@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NullOutput;
 
-our $DATE = '2017-06-26'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2017-06-28'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,6 +11,8 @@ our $scenario = {
     summary => 'Benchmark Log::ger logging speed with the default/null output',
     modules => {
         'Log::ger' => {version=>'0.005'},
+        'Log::ger::Plugin::SingleLog' => {},
+        'Log::ger::Plugin::OptAway' => {},
         'Log::Any' => {},
         'Log::Fast' => {},
     },
@@ -24,9 +26,17 @@ our $scenario = {
             perl_cmdline_template => ['-MLog::ger', '-e', 'for(1..1_000_000) { log_is_trace() }'],
         },
         {
-            name => 'Log::ger+Log::ger::Plugin::OptAway-1mil_log_trace',
+            name => 'Log::ger+LGP:OptAway-1mil_log_trace',
             perl_cmdline_template => ['-MLog::ger::Plugin=OptAway', '-MLog::ger', '-e', 'for(1..1_000_000) { log_trace(q[]) }'],
         },
+        {
+            name => 'Log::ger+LGP:SingleLog-1mil_log_trace',
+            perl_cmdline_template => ['-MLog::ger::Plugin=SingleLog', '-MLog::ger', '-e', 'for(1..1_000_000) { log("trace", q[]) }'],
+        },
+        {
+            name => 'Log::ger+LGP:SingleLog-1mil_log_6',
+            perl_cmdline_template => ['-MLog::ger::Plugin=SingleLog', '-MLog::ger', '-e', 'for(1..1_000_000) { log(6, q[]) }'],
+        },
 
         {
             name => 'Log::Fast-1mil_DEBUG',
@@ -72,7 +82,7 @@ Bencher::Scenario::LogGer::NullOutput - Benchmark Log::ger logging speed with th
 
 =head1 VERSION
 
-This document describes version 0.005 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-26.
+This document describes version 0.006 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-28.
 
 =head1 SYNOPSIS
 
@@ -94,7 +104,11 @@ L<Log::Any> 1.045
 
 L<Log::Fast> v2.0.0
 
-L<Log::ger> 0.008
+L<Log::ger> 0.010
+
+L<Log::ger::Plugin::OptAway> 0.003
+
+L<Log::ger::Plugin::SingleLog> 0.001
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -116,7 +130,7 @@ Command line:
 
 
 
-=item * Log::ger+Log::ger::Plugin::OptAway-1mil_log_trace (command)
+=item * Log::ger+LGP:OptAway-1mil_log_trace (command)
 
 Command line:
 
@@ -124,6 +138,22 @@ Command line:
 
 
 
+=item * Log::ger+LGP:SingleLog-1mil_log_trace (command)
+
+Command line:
+
+ #TEMPLATE: #perl -MLog::ger::Plugin=SingleLog -MLog::ger -e for(1..1_000_000) { log("trace", q[]) }
+
+
+
+=item * Log::ger+LGP:SingleLog-1mil_log_6 (command)
+
+Command line:
+
+ #TEMPLATE: #perl -MLog::ger::Plugin=SingleLog -MLog::ger -e for(1..1_000_000) { log(6, q[]) }
+
+
+
 =item * Log::Fast-1mil_DEBUG (command)
 
 Command line:
@@ -181,19 +211,21 @@ Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (
 Benchmark with default options (C<< bencher -m LogGer::NullOutput >>):
 
  #table1#
- +---------------------------------------------------+-----------+-----------+------------+-----------+---------+
- | participant                                       | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
- +---------------------------------------------------+-----------+-----------+------------+-----------+---------+
- | Log::Any-null_adapter-1mil_log_trace              |      2.48 |       403 |       1    |   0.00015 |       6 |
- | Log::Fast-1mil_is_debug                           |      3.4  |       300 |       1.4  |   0.00039 |       6 |
- | Log::Any-no_adapter-1mil_is_trace                 |      4.1  |       240 |       1.7  |   0.00043 |       6 |
- | Log::Any-null_adapter-1mil_is_trace               |      4.16 |       240 |       1.68 |   0.00018 |       6 |
- | Log::Any-no_adapter-1mil_log_trace                |     11    |        91 |       4.4  |   0.00032 |       7 |
- | Log::Fast-1mil_DEBUG                              |     11    |        90 |       4.5  |   0.00057 |       6 |
- | Log::ger-1mil_log_is_trace                        |     16    |        61 |       6.6  |   0.00019 |       6 |
- | Log::ger-1mil_log_trace                           |     18    |        55 |       7.3  | 5.5e-05   |       6 |
- | Log::ger+Log::ger::Plugin::OptAway-1mil_log_trace |     38    |        26 |      15    |   0.00018 |       6 |
- +---------------------------------------------------+-----------+-----------+------------+-----------+---------+
+ +---------------------------------------+-----------+-----------+------------+---------+---------+
+ | participant                           | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +---------------------------------------+-----------+-----------+------------+---------+---------+
+ | Log::ger+LGP:SingleLog-1mil_log_6     |      1.8  |       560 |       1    | 0.0016  |       6 |
+ | Log::ger+LGP:SingleLog-1mil_log_trace |      2    |       510 |       1.1  | 0.00089 |       7 |
+ | Log::Any-null_adapter-1mil_log_trace  |      2.46 |       407 |       1.37 | 0.00031 |       6 |
+ | Log::Fast-1mil_is_debug               |      3.32 |       301 |       1.85 | 0.00014 |       8 |
+ | Log::Any-null_adapter-1mil_is_trace   |      4    |       250 |       2.2  | 0.0011  |       6 |
+ | Log::Any-no_adapter-1mil_is_trace     |      4.1  |       250 |       2.3  | 0.0011  |       9 |
+ | Log::Any-no_adapter-1mil_log_trace    |     11    |        93 |       6    | 0.00072 |       6 |
+ | Log::Fast-1mil_DEBUG                  |     11    |        91 |       6.1  | 0.00035 |       6 |
+ | Log::ger-1mil_log_is_trace            |     16    |        61 |       9.1  | 0.0003  |       6 |
+ | Log::ger-1mil_log_trace               |     18    |        56 |       9.9  | 0.00021 |       7 |
+ | Log::ger+LGP:OptAway-1mil_log_trace   |     35    |        28 |      20    | 0.00019 |       7 |
+ +---------------------------------------+-----------+-----------+------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
