@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::Startup;
 
-our $DATE = '2017-06-26'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2017-06-28'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 
 our $scenario = {
     modules => {
-        'Log::ger' => {version=>'0.008'},
+        'Log::ger' => {version=>'0.010'},
     },
     participants => [
         {name=>"baseline", perl_cmdline => ["-e1"]},
@@ -41,7 +41,7 @@ Bencher::Scenario::LogGer::Startup
 
 =head1 VERSION
 
-This document describes version 0.005 of Bencher::Scenario::LogGer::Startup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-26.
+This document describes version 0.006 of Bencher::Scenario::LogGer::Startup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-28.
 
 =head1 SYNOPSIS
 
@@ -67,7 +67,7 @@ L<Log::Any> 1.045
 
 L<Log::Any::Adapter::Screen> 0.13
 
-L<Log::ger> 0.008
+L<Log::ger> 0.010
 
 L<Log::ger::Like::LogAny> 0.001
 
@@ -137,15 +137,15 @@ Benchmark with C<< bencher -m LogGer::Startup --include-path archive/Log-Any-0.1
  +----------------------------------------------+--------+-----------+-----------+------------+---------+---------+
  | participant                                  | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +----------------------------------------------+--------+-----------+-----------+------------+---------+---------+
- | use Log::Any + use Log::Any::Adapter::Screen |        |       120 |       8.1 |        1   |   2e-05 |      20 |
- | use Log::Any                                 | 1.045  |       150 |       6.7 |        1.2 | 2.4e-05 |      20 |
- | use Log::ger + use Log::ger::Output::Screen  |        |       190 |       5.3 |        1.5 | 2.2e-05 |      20 |
- | use Log::ger::Like::LogAny                   |        |       230 |       4.4 |        1.8 | 1.6e-05 |      20 |
- | use Log::ger + use Log::ger::Plugin::OptAway |        |       280 |       3.6 |        2.3 | 1.8e-05 |      20 |
- | use Log::Any                                 | 0.15   |       330 |       3   |        2.7 |   9e-06 |      20 |
- | use Log::ger                                 |        |       480 |       2.1 |        3.9 | 1.3e-05 |      23 |
- | use Log::ger ()                              |        |       500 |       2   |        4   | 1.1e-05 |      20 |
- | baseline                                     |        |       830 |       1.2 |        6.7 | 7.4e-06 |      20 |
+ | use Log::Any + use Log::Any::Adapter::Screen |        |       120 |       8.3 |        1   | 2.3e-05 |      20 |
+ | use Log::Any                                 | 1.045  |       150 |       6.8 |        1.2 |   3e-05 |      21 |
+ | use Log::ger + use Log::ger::Output::Screen  |        |       190 |       5.4 |        1.5 | 1.6e-05 |      22 |
+ | use Log::ger::Like::LogAny                   |        |       220 |       4.5 |        1.8 | 1.4e-05 |      20 |
+ | use Log::ger + use Log::ger::Plugin::OptAway |        |       280 |       3.6 |        2.3 | 1.4e-05 |      20 |
+ | use Log::Any                                 | 0.15   |       330 |       3   |        2.7 | 1.1e-05 |      20 |
+ | use Log::ger                                 |        |       460 |       2.2 |        3.8 | 9.1e-06 |      20 |
+ | use Log::ger ()                              |        |       470 |       2.1 |        3.9 | 1.1e-05 |      20 |
+ | baseline                                     |        |       830 |       1.2 |        6.8 | 4.5e-06 |      20 |
  +----------------------------------------------+--------+-----------+-----------+------------+---------+---------+
 
 
@@ -155,13 +155,13 @@ Benchmark module startup overhead (C<< bencher -m LogGer::Startup --module-start
  +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant               | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Log::Any::Adapter::Screen | 1.5                          | 4.9                | 21             |       9.8 |                    7.1 |        1   |   3e-05 |      20 |
- | Log::Any                  | 1.2                          | 4.5                | 20             |       8.5 |                    5.8 |        1.2 | 1.4e-05 |      20 |
- | Log::ger::Like::LogAny    | 0.86                         | 4.1                | 20             |       6.1 |                    3.4 |        1.6 |   2e-05 |      20 |
- | Log::ger::Plugin::OptAway | 1                            | 4.3                | 20             |       4.3 |                    1.6 |        2.3 | 1.9e-05 |      20 |
- | Log::ger::Output::Screen  | 0.84                         | 4.2                | 20             |       4.3 |                    1.6 |        2.3 | 5.5e-06 |      22 |
- | Log::ger                  | 1                            | 4.3                | 20             |       3.8 |                    1.1 |        2.6 | 1.6e-05 |      20 |
- | perl -e1 (baseline)       | 0.82                         | 4.1                | 20             |       2.7 |                    0   |        3.7 | 8.7e-06 |      21 |
+ | Log::Any::Adapter::Screen | 1.5                          | 4.9                | 21             |      10   |                    7   |        1   |   6e-05 |      20 |
+ | Log::Any                  | 1.2                          | 4.5                | 20             |       9.5 |                    6.5 |        1.1 | 3.2e-05 |      20 |
+ | Log::ger::Like::LogAny    | 0.86                         | 4.1                | 20             |       7.2 |                    4.2 |        1.5 | 5.8e-05 |      20 |
+ | Log::ger::Output::Screen  | 0.84                         | 4.1                | 20             |       4.9 |                    1.9 |        2.1 | 1.2e-05 |      23 |
+ | Log::ger::Plugin::OptAway | 1                            | 4.3                | 20             |       4.9 |                    1.9 |        2.1 | 1.2e-05 |      20 |
+ | Log::ger                  | 1                            | 4.4                | 20             |       4.3 |                    1.3 |        2.4 | 9.8e-06 |      22 |
+ | perl -e1 (baseline)       | 0.8                          | 4                  | 20             |       3   |                    0   |        3   | 3.7e-05 |      20 |
  +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
