@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::OutputStartup;
 
-our $VERSION = 0.005; # VERSION
+our $VERSION = 0.006; # VERSION
 
 our $results = [
   [
@@ -8,7 +8,7 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00011,
+        errors => 7.6e-05,
         participant => "init-with-FileWriteRotate",
         rate => 33,
         samples => 20,
@@ -16,196 +16,196 @@ our $results = [
         vs_slowest => 1,
       },
       {
-        errors => 3.4e-05,
+        errors => 6e-05,
         participant => "init-with-LogDispatchOutput",
-        rate => 58,
-        samples => 20,
-        time => 17,
-        vs_slowest => 1.8,
+        rate => 55,
+        samples => 21,
+        time => 18,
+        vs_slowest => 1.7,
       },
       {
-        errors => 4.6e-05,
+        errors => 0.0001,
         participant => "init-with-Composite",
-        rate => 86,
-        samples => 20,
-        time => 12,
-        vs_slowest => 2.6,
+        rate => 78,
+        samples => 23,
+        time => 13,
+        vs_slowest => 2.4,
       },
       {
-        errors => 2.5e-05,
+        errors => 3.9e-05,
         participant => "init-with-LogAny",
-        rate => 86,
+        rate => 79,
         samples => 20,
-        time => 12,
-        vs_slowest => 2.6,
+        time => 13,
+        vs_slowest => 2.4,
       },
       {
         errors => 4.5e-05,
         participant => "init-with-DirWriteRotate",
-        rate => 110,
+        rate => 95,
+        samples => 20,
+        time => 11,
+        vs_slowest => 2.9,
+      },
+      {
+        errors => 4.3e-05,
+        participant => "init-with-Array",
+        rate => 130,
+        samples => 20,
+        time => 7.6,
+        vs_slowest => 4,
+      },
+      {
+        errors => 1.5e-05,
+        participant => "init-with-Null",
+        rate => 130,
+        samples => 22,
+        time => 7.6,
+        vs_slowest => 4,
+      },
+      {
+        errors => 4.2e-05,
+        participant => "init-with-ArrayWithLimits",
+        rate => 130,
+        samples => 20,
+        time => 7.5,
+        vs_slowest => 4.1,
+      },
+      {
+        errors => 1.5e-05,
+        participant => "init-with-Callback",
+        rate => 130,
         samples => 21,
-        time => 9.4,
-        vs_slowest => 3.2,
+        time => 7.5,
+        vs_slowest => 4.1,
       },
       {
         errors => 2.5e-05,
+        participant => "init-with-String",
+        rate => 130,
+        samples => 22,
+        time => 7.4,
+        vs_slowest => 4.1,
+      },
+      {
+        errors => 3.9e-05,
         participant => "init-with-File",
+        rate => 130,
+        samples => 22,
+        time => 7.4,
+        vs_slowest => 4.1,
+      },
+      {
+        errors => 3.7e-05,
+        participant => "init-with-Screen",
         rate => 140,
         samples => 20,
-        time => 6.9,
-        vs_slowest => 4.4,
-      },
-      {
-        errors => 2.3e-05,
-        participant => "init-with-ArrayWithLimits",
-        rate => 150,
-        samples => 22,
-        time => 6.9,
-        vs_slowest => 4.4,
-      },
-      {
-        errors => 2.6e-05,
-        participant => "init-with-Array",
-        rate => 150,
-        samples => 20,
-        time => 6.8,
-        vs_slowest => 4.4,
-      },
-      {
-        errors => 1.7e-05,
-        participant => "init-with-Screen",
-        rate => 150,
-        samples => 20,
-        time => 6.8,
-        vs_slowest => 4.4,
+        time => 7.4,
+        vs_slowest => 4.1,
       },
       {
         errors => 2e-05,
-        participant => "init-with-Callback",
-        rate => 150,
-        samples => 21,
-        time => 6.8,
-        vs_slowest => 4.4,
-      },
-      {
-        errors => 1.2e-05,
-        participant => "init-with-String",
-        rate => 150,
-        samples => 20,
-        time => 6.8,
-        vs_slowest => 4.5,
-      },
-      {
-        errors => 1.1e-05,
-        participant => "init-with-Null",
-        rate => 150,
-        samples => 20,
-        time => 6.6,
-        vs_slowest => 4.6,
-      },
-      {
-        errors => 1.1e-05,
         participant => "load-LogDispatchOutput",
-        rate => 180,
+        rate => 160,
         samples => 20,
-        time => 5.7,
-        vs_slowest => 5.3,
+        time => 6.3,
+        vs_slowest => 4.8,
       },
       {
-        errors => 3.2e-05,
+        errors => 2.6e-05,
         participant => "load-Composite",
+        rate => 200,
+        samples => 20,
+        time => 5,
+        vs_slowest => 6.1,
+      },
+      {
+        errors => 3.4e-05,
+        participant => "load-Callback",
         rate => 210,
         samples => 20,
-        time => 4.7,
+        time => 4.8,
+        vs_slowest => 6.3,
+      },
+      {
+        errors => 2.3e-05,
+        participant => "load-LogAny",
+        rate => 210,
+        samples => 21,
+        time => 4.8,
+        vs_slowest => 6.3,
+      },
+      {
+        errors => 3.4e-05,
+        participant => "load-Screen",
+        rate => 210,
+        samples => 20,
+        time => 4.8,
         vs_slowest => 6.4,
       },
       {
-        errors => 1.8e-05,
-        participant => "load-LogAny",
+        errors => 3.1e-05,
+        participant => "load-FileWriteRotate",
+        rate => 210,
+        samples => 21,
+        time => 4.7,
+        vs_slowest => 6.5,
+      },
+      {
+        errors => 1.9e-05,
+        participant => "load-File",
+        rate => 210,
+        samples => 20,
+        time => 4.7,
+        vs_slowest => 6.5,
+      },
+      {
+        errors => 1.9e-05,
+        participant => "load-String",
+        rate => 210,
+        samples => 23,
+        time => 4.7,
+        vs_slowest => 6.5,
+      },
+      {
+        errors => 2.5e-05,
+        participant => "load-Array",
+        rate => 220,
+        samples => 20,
+        time => 4.6,
+        vs_slowest => 6.6,
+      },
+      {
+        errors => 1.2e-05,
+        participant => "load-DirWriteRotate",
+        rate => 220,
+        samples => 20,
+        time => 4.5,
+        vs_slowest => 6.7,
+      },
+      {
+        errors => 2e-05,
+        participant => "load-ArrayWithLimits",
         rate => 230,
         samples => 20,
         time => 4.4,
         vs_slowest => 6.9,
       },
       {
-        errors => 1e-05,
-        participant => "load-Screen",
-        rate => 230,
-        samples => 20,
-        time => 4.3,
-        vs_slowest => 7.1,
-      },
-      {
-        errors => 2e-05,
-        participant => "load-Callback",
-        rate => 230,
-        samples => 21,
-        time => 4.3,
-        vs_slowest => 7.1,
-      },
-      {
-        errors => 1.7e-05,
-        participant => "load-FileWriteRotate",
-        rate => 230,
-        samples => 20,
-        time => 4.3,
-        vs_slowest => 7.1,
-      },
-      {
-        errors => 2.1e-05,
-        participant => "load-File",
-        rate => 230,
-        samples => 21,
-        time => 4.3,
-        vs_slowest => 7.1,
-      },
-      {
-        errors => 1.9e-05,
-        participant => "load-String",
-        rate => 230,
-        samples => 21,
-        time => 4.3,
-        vs_slowest => 7.1,
-      },
-      {
-        errors => 9.6e-06,
-        participant => "load-DirWriteRotate",
-        rate => 240,
-        samples => 20,
-        time => 4.2,
-        vs_slowest => 7.2,
-      },
-      {
-        errors => 1.6e-05,
-        participant => "load-Array",
-        rate => 240,
-        samples => 21,
-        time => 4.2,
-        vs_slowest => 7.2,
-      },
-      {
-        errors => 1.4e-05,
-        participant => "load-ArrayWithLimits",
-        rate => 240,
-        samples => 20,
-        time => 4.2,
-        vs_slowest => 7.2,
-      },
-      {
-        errors => 1.6e-05,
+        errors => 1.1e-05,
         participant => "load-Null",
-        rate => 350,
+        rate => 320,
         samples => 20,
-        time => 2.9,
-        vs_slowest => 11,
+        time => 3.1,
+        vs_slowest => 9.9,
       },
       {
-        errors => 1.4e-05,
+        errors => 2.7e-06,
         participant => "baseline",
-        rate => 390,
+        rate => 367,
         samples => 20,
-        time => 2.6,
-        vs_slowest => 12,
+        time => 2.73,
+        vs_slowest => 11.2,
       },
     ],
     {
@@ -323,7 +323,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 0,
-                                              speed                        => "3823.140",
+                                              speed                        => 3856.343,
                                               stepping                     => 3,
                                             },
                                             {
@@ -433,7 +433,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 1,
-                                              speed                        => "3806.140",
+                                              speed                        => 3836.953,
                                               stepping                     => 3,
                                             },
                                             {
@@ -543,7 +543,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 2,
-                                              speed                        => 3861.921,
+                                              speed                        => 3870.156,
                                               stepping                     => 3,
                                             },
                                             {
@@ -653,7 +653,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 3,
-                                              speed                        => 3887.421,
+                                              speed                        => 3884.234,
                                               stepping                     => 3,
                                             },
                                             {
@@ -763,7 +763,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 4,
-                                              speed                        => 3891.539,
+                                              speed                        => "3791.000",
                                               stepping                     => 3,
                                             },
                                             {
@@ -873,7 +873,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 5,
-                                              speed                        => 3898.312,
+                                              speed                        => 3801.359,
                                               stepping                     => 3,
                                             },
                                             {
@@ -983,7 +983,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 6,
-                                              speed                        => 3773.335,
+                                              speed                        => 3895.523,
                                               stepping                     => 3,
                                             },
                                             {
@@ -1093,18 +1093,18 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 7,
-                                              speed                        => "3863.250",
+                                              speed                        => 3899.773,
                                               stepping                     => 3,
                                             },
                                           ],
-      "func.elapsed_time"              => 4.94350004196167,
+      "func.elapsed_time"              => 5.40375208854675,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                              => 1.036,
                                             "Bencher::Scenario::LogGer::OutputStartup" => undef,
                                             "Benchmark::Dumb"                          => "0.10",
                                             "Devel::Platform::Info"                    => 0.16,
-                                            "Log::ger::Output::Array"                  => 0.008,
+                                            "Log::ger::Output::Array"                  => "0.010",
                                             "Log::ger::Output::ArrayWithLimits"        => 0.001,
                                             "Log::ger::Output::Callback"               => 0.001,
                                             "Log::ger::Output::Composite"              => 0.004,
@@ -1113,9 +1113,9 @@ our $results = [
                                             "Log::ger::Output::FileWriteRotate"        => 0.001,
                                             "Log::ger::Output::LogAny"                 => 0.006,
                                             "Log::ger::Output::LogDispatchOutput"      => 0.001,
-                                            "Log::ger::Output::Null"                   => 0.008,
+                                            "Log::ger::Output::Null"                   => "0.010",
                                             "Log::ger::Output::Screen"                 => 0.004,
-                                            "Log::ger::Output::String"                 => 0.008,
+                                            "Log::ger::Output::String"                 => "0.010",
                                             "perl"                                     => "v5.24.0",
                                             "Sys::Info"                                => 0.78,
                                           },
@@ -1150,9 +1150,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1498449729,
       "func.scenario_module_sha1sum"   => "0389ae613ac5ab14f9accef3e8dd982546902675",
       "func.scenario_module_sha256sum" => "0a4e1e5e5c42944c030a62cb5f532fde7cdacd07c6f85077bab8c993aa51ce6f",
-      "func.time_end"                  => 1498451477.8725,
+      "func.time_end"                  => 1498617893.70582,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498451472.929,
+      "func.time_start"                => 1498617888.30206,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
