@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::Startup;
 
-our $VERSION = 0.005; # VERSION
+our $VERSION = 0.006; # VERSION
 
 our $results = [
   [
@@ -8,43 +8,43 @@ our $results = [
     "OK",
     [
       {
-        errors      => 2e-05,
+        errors      => 2.3e-05,
         modver      => "",
         participant => "use Log::Any + use Log::Any::Adapter::Screen",
         rate        => 120,
         samples     => 20,
-        time        => 8.1,
+        time        => 8.3,
         vs_slowest  => 1,
       },
       {
-        errors      => 2.4e-05,
+        errors      => 3e-05,
         modver      => 1.045,
         participant => "use Log::Any",
         rate        => 150,
-        samples     => 20,
-        time        => 6.7,
+        samples     => 21,
+        time        => 6.8,
         vs_slowest  => 1.2,
       },
-      {
-        errors      => 2.2e-05,
-        modver      => "",
-        participant => "use Log::ger + use Log::ger::Output::Screen",
-        rate        => 190,
-        samples     => 20,
-        time        => 5.3,
-        vs_slowest  => 1.5,
-      },
       {
         errors      => 1.6e-05,
         modver      => "",
+        participant => "use Log::ger + use Log::ger::Output::Screen",
+        rate        => 190,
+        samples     => 22,
+        time        => 5.4,
+        vs_slowest  => 1.5,
+      },
+      {
+        errors      => 1.4e-05,
+        modver      => "",
         participant => "use Log::ger::Like::LogAny",
-        rate        => 230,
+        rate        => 220,
         samples     => 20,
-        time        => 4.4,
+        time        => 4.5,
         vs_slowest  => 1.8,
       },
       {
-        errors      => 1.8e-05,
+        errors      => 1.4e-05,
         modver      => "",
         participant => "use Log::ger + use Log::ger::Plugin::OptAway",
         rate        => 280,
@@ -53,7 +53,7 @@ our $results = [
         vs_slowest  => 2.3,
       },
       {
-        errors      => 9e-06,
+        errors      => 1.1e-05,
         modver      => 0.15,
         participant => "use Log::Any",
         rate        => 330,
@@ -62,31 +62,31 @@ our $results = [
         vs_slowest  => 2.7,
       },
       {
-        errors      => 1.3e-05,
+        errors      => 9.1e-06,
         modver      => "",
         participant => "use Log::ger",
-        rate        => 480,
-        samples     => 23,
-        time        => 2.1,
-        vs_slowest  => 3.9,
+        rate        => 460,
+        samples     => 20,
+        time        => 2.2,
+        vs_slowest  => 3.8,
       },
       {
         errors      => 1.1e-05,
         modver      => "",
         participant => "use Log::ger ()",
-        rate        => 500,
+        rate        => 470,
         samples     => 20,
-        time        => 2,
-        vs_slowest  => 4,
+        time        => 2.1,
+        vs_slowest  => 3.9,
       },
       {
-        errors      => 7.4e-06,
+        errors      => 4.5e-06,
         modver      => "",
         participant => "baseline",
         rate        => 830,
         samples     => 20,
         time        => 1.2,
-        vs_slowest  => 6.7,
+        vs_slowest  => 6.8,
       },
     ],
     {
@@ -206,7 +206,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 0,
-                                              speed                        => 3893.398,
+                                              speed                        => 3822.875,
                                               stepping                     => 3,
                                             },
                                             {
@@ -316,7 +316,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 1,
-                                              speed                        => 3813.976,
+                                              speed                        => "3827.390",
                                               stepping                     => 3,
                                             },
                                             {
@@ -426,7 +426,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 2,
-                                              speed                        => 3791.531,
+                                              speed                        => 3792.062,
                                               stepping                     => 3,
                                             },
                                             {
@@ -536,7 +536,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 3,
-                                              speed                        => "3788.210",
+                                              speed                        => 3871.617,
                                               stepping                     => 3,
                                             },
                                             {
@@ -646,7 +646,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 4,
-                                              speed                        => "3784.890",
+                                              speed                        => 3894.195,
                                               stepping                     => 3,
                                             },
                                             {
@@ -756,7 +756,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 5,
-                                              speed                        => "3897.250",
+                                              speed                        => 3898.312,
                                               stepping                     => 3,
                                             },
                                             {
@@ -866,7 +866,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 6,
-                                              speed                        => 3898.578,
+                                              speed                        => "3896.320",
                                               stepping                     => 3,
                                             },
                                             {
@@ -976,7 +976,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 7,
-                                              speed                        => 3898.578,
+                                              speed                        => 3893.664,
                                               stepping                     => 3,
                                             },
                                           ],
@@ -988,7 +988,7 @@ our $results = [
                                             "Devel::Platform::Info" => 0.16,
                                             "Log::Any" => 1.045,
                                             "Log::Any::Adapter::Screen" => 0.13,
-                                            "Log::ger" => 0.008,
+                                            "Log::ger" => "0.010",
                                             "Log::ger::Like::LogAny" => 0.001,
                                             "Log::ger::Output::Screen" => 0.004,
                                             "Log::ger::Plugin::OptAway" => 0.003,
@@ -1000,7 +1000,7 @@ our $results = [
                                             "perl",
                                             ["perl"],
                                             "modver",
-                                            [1.045, 0.15],
+                                            [0.15, 1.045],
                                             "participant",
                                             [0 .. 7],
                                           ],
@@ -1029,12 +1029,12 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::Startup",
-      "func.scenario_module_md5sum"    => "65405378a4ed788ea870a5ec171b0914",
-      "func.scenario_module_mtime"     => 1498451419,
-      "func.scenario_module_sha1sum"   => "45c8fce112802f29e26307221c554cb509e0948f",
-      "func.scenario_module_sha256sum" => "d2d0107b8c0a6eb02a1bbdd1c1a0ffab446371c4d310be7aa8b2dc9c2b2451ac",
+      "func.scenario_module_md5sum"    => "d6fa870e804242b51756b66fba8c4b7c",
+      "func.scenario_module_mtime"     => 1498617817,
+      "func.scenario_module_sha1sum"   => "54ea09103e3b6dee3aed5c6404117751cb0af292",
+      "func.scenario_module_sha256sum" => "c374a16ca36d2669c65018f688dada719a7eb2d2aa8f06624e405675dc73f712",
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498451479.95537,
+      "func.time_start"                => 1498617895.9954,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
